==> thunder-8.x-1.0-no-core.tar.gz: thunder/modules/nexx_integration/src/Plugin/Field/FieldWidget/NexxVideoInfo.php <==
<?php

namespace Drupal\nexx_integration\Plugin\Field\FieldWidget;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'nexx_video_info' widget.
 *
 * @FieldWidget(
 *   id = "nexx_video_info",
 *   module = "nexx_integration",
 *   label = @Translation("Video info as provided by nexxOMNIA calls"),
 *   field_types = {
 *     "nexx_video_data"
 *   }
 * )
 */
class NexxVideoInfo extends WidgetBase implements ContainerFactoryPluginInterface {
  /**
   * The config factory.
   *
   * @var ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * {@inheritdoc}
   */
  public function __construct(
    $plugin_id,
    $plugin_definition,
    FieldDefinitionInterface $field_definition,
    array $settings,
    array $third_party_settings,
    ConfigFactoryInterface $config_factory
  ) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $third_party_settings);

    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id,
    $plugin_definition
  ) {
    return new static(
      $plugin_id,
      $plugin_definition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['third_party_settings'],
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function formElement(
    FieldItemListInterface $items,
    $delta,
    array $element,
    array &$form,
    FormStateInterface $form_state
  ) {

    $element['item_id'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Item ID'),
      '#default_value' => isset($items[$delta]->item_id) ? $items[$delta]->item_id : 0,
      '#description' => $this->t('nexxOMNIA item ID.'),
      '#required' => FALSE,
    );
    return $element;
  }

}

==> thunder-8.x-2.0-no-core.tar.gz: thunder/modules/nexx_integration/src/Plugin/Field/FieldWidget/NexxVideoInfo.php <==
<?php

namespace Drupal\nexx_integration\Plugin\Field\FieldWidget;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'nexx_video_info' widget.
 *
 * @FieldWidget(
 *   id = "nexx_video_info",
 *   module = "nexx_integration",
 *   label = @Translation("Video info as provided by nexxOMNIA calls"),
 *   field_types = {
 *     "nexx_video_data"
 *   }
 * )
 */
class NexxVideoInfo extends WidgetBase implements ContainerFactoryPluginInterface {
  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * {@inheritdoc}
   */
  public function __construct(
    $plugin_id,
    $plugin_definition,
    FieldDefinitionInterface $field_definition,
    array $settings,
    array $third_party_settings,
    ConfigFactoryInterface $config_factory
  ) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $third_party_settings);

    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id,
    $plugin_definition
  ) {
    return new static(
      $plugin_id,
      $plugin_definition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['third_party_settings'],
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function formElement(
    FieldItemListInterface $items,
    $delta,
    array $element,
    array &$form,
    FormStateInterface $form_state
  ) {

    $element['item_id'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Item ID'),
      '#default_value' => isset($items[$delta]->item_id) ? $items[$delta]->item_id : 0,
      '#description' => $this->t('nexxOMNIA item ID.'),
      '#required' => FALSE,
    );
    return $element;
  }

}
